VectorMatcherMetadata

Struct VectorMatcherMetadata 

pub struct VectorMatcherMetadata { /* private fields */ }
Convenience metadata for vectors.

Unlike FixedShapeTensor, the Vector type has EmptyMetadata as its metadata because all of the important information is already stored in the dtype.

However, it is quite inconvenient to repeatedly unwrap the dtype to get the element type of the vector and the number of dimensions.

Thus, we allow the matcher to return this metadata so that we can access this information more easily.

Implementations

Source

impl VectorMatcherMetadata

pub fn try_new(element_ptype: PType, dimensions: u32) -> VortexResult<Self>

Tries to create a new VectorMatcherMetadata.

Errors

Returns an error if the element type is not a float.

pub fn element_ptype(&self) -> PType

Returns the element type of the vectors.

pub fn dimensions(&self) -> u32

Returns the number of dimensions of the vector.