Types and functionality for working with tensors, vectors, and related mathematical constructs including unit vectors, spherical coordinates, and similarity measures such as cosine similarity.
Modules
- encodings
- Encodings for the different tensor types.
- fixed_
shape - Fixed-shape Tensor extension type.
- matcher
- Matcher for tensor-like extension types.
- scalar_
fns - Scalar function expressions defined on tensor and tensor-like extension types.
- vector
- Vector extension type for fixed-length float vectors (e.g., embeddings).
- vector_
search - Reusable helpers for building brute-force vector similarity search expressions over
Vectorextension arrays.
Constants
- SCALAR_
FN_ ARRAY_ TENSOR_ PLUGIN_ ENV - Environment variable that gates registration of the tensor scalar-fn array plugins (the array
encodings that let
CosineSimilarity,InnerProduct,L2Denorm,L2Norm, andSorfTransformpersist in a Vortex file). When unset, only the scalar functions themselves are registered; readers of files containing serialized tensor scalar-fn arrays will fail to deserialize. Opt-in by setting the variable to any non-empty value.
Functions
- initialize
- Initialize the Vortex tensor library with a Vortex session.