Crate vortex_tensor

Crate vortex_tensor 

Types and functionality for working with tensors, vectors, and related mathematical constructs including unit vectors, spherical coordinates, and similarity measures such as cosine similarity.

Modules

encodings
Encodings for the different tensor types.
fixed_shape
Fixed-shape Tensor extension type.
matcher
Matcher for tensor-like extension types.
scalar_fns
Scalar function expressions defined on tensor and tensor-like extension types.
vector
Vector extension type for fixed-length float vectors (e.g., embeddings).

Functions

initialize
Initialize the Vortex tensor library with a Vortex session.