Crate vortex_tensor

Crate vortex_tensor 

Types and functionality for working with tensors, vectors, and related mathematical constructs including unit vectors, spherical coordinates, and similarity measures such as cosine similarity.

Modules

fixed_shape
Fixed-shape Tensor extension type.
scalar_fns