Types and functionality for working with tensors, vectors, and related mathematical constructs including unit vectors, spherical coordinates, and similarity measures such as cosine similarity.
Modules
- fixed_
shape - Fixed-shape Tensor extension type.
- scalar_
fns